// cpp/translation_stubs.h

#ifndef CPP_TRANSLATION_STUBS_H
#define CPP_TRANSLATION_STUBS_H

// Declared in mycpp/comparators.h
inline bool items_equal(id_kind_asdl::Kind left, id_kind_asdl::Kind right) {
  return left == right;
}

#endif  // CPP_TRANSLATION_STUBS_H
